--------
In / Out
--------

ADS1115
+++++++
.. automodule:: crappy.inout.ads1115
   :members:

Agilent 34420A
++++++++++++++
.. automodule:: crappy.inout.agilent34420A
   :members:

Arduino
+++++++
.. automodule:: crappy.inout.arduino
   :members:

Comedi
++++++
.. automodule:: crappy.inout.comedi
   :members:

DaQMX
+++++
.. automodule:: crappy.inout.daqmx
   :members:

GPIO PWM
++++++++
.. automodule:: crappy.inout.gpio_pwm
   :members:

GPIO switch
+++++++++++
.. automodule:: crappy.inout.gpio_switch
   :members:

GSM
+++
.. automodule:: crappy.inout.gsm
   :members:

InOut
+++++
.. automodule:: crappy.inout.inout
   :members:

Kollmorgen
++++++++++
.. automodule:: crappy.inout.kollmorgen
   :members:

Labjack T7
++++++++++
.. automodule:: crappy.inout.labjackT7
   :members:

Labjack UE9
+++++++++++
.. automodule:: crappy.inout.labjackUE9
   :members:

MCP9600
+++++++
.. automodule:: crappy.inout.mcp9600
   :members:

MPRLS
+++++++
.. automodule:: crappy.inout.mprls
   :members:

NAU7802
+++++++
.. automodule:: crappy.inout.nau7802
   :members:

NI DaQMX
++++++++
.. automodule:: crappy.inout.ni_daqmx
   :members:

Open DaQ
++++++++
.. automodule:: crappy.inout.open_daq
   :members:

Opsens
++++++
.. automodule:: crappy.inout.opsens
   :members:

PiJuice
+++++++
.. automodule:: crappy.inout.piJuice
   :members:

Spectrum
++++++++
.. automodule:: crappy.inout.spectrum
   :members:

T7 Streamer
+++++++++++
.. automodule:: crappy.inout.t7Streamer
   :members:

Waveshare AD/DA
+++++++++++++++
.. automodule:: crappy.inout.waveshare_ad_da
   :members:

Waveshare AD/DA FT232H
++++++++++++++++++++++
.. automodule:: crappy.inout.waveshare_ad_da_ft232h
   :members:
